# Basic Pretzel Application

The Pretzel suite comes with a very small core consisting of about 144 lines split
into 3 modules: Core, Routing::Evaluation and Routing::Methods. Every Pretzel application
also automatically includes the Extension::Convenience module which provides some
neat wrappers around common functionality.

## Directory structure

Before we get down and dirty with the code, let's talk management. The Pretzel suite
has strong opinions on where things should go. The basic folder structure for a Pretzel
application looks like this:

```
  my_app
  |
  |- config.ru
  |- application.rb
  |- assets
  |- views
      |- includes

```

`config.ru` is your rackup file. You can read more about that down below. The `application.rb`
file can be named whatever you want, and it should contain the class declaration
your application.

The `assets` directory is a folder for your static content. CSS/JS, images, etc.
Everything is mapped 1-to-1 in the URL scheme, so if you put a file under `/assets/css/style.css`
you will find it under `/assets/css/style.css` when the application is running.

The `views` folder is where your `liquid` templates go. (See 03-00-templating for more
information). The `includes` folder inside contains the `liquid` partials. 

**NOTE:** These settings are fixed and may not be changed at runtime. Convention over
configuration takes effect here.

## Creating an application

A basic Pretzel application consists of a class inheriting from the Pretzel::Core
class. It looks like this:

```ruby
  require "pretzel/core"

  class Application < Pretzel::Core
  end
```

This gives you the following functionality:

  * Routing with 6 methods (`GET, POST, PUT, DELETE, OPTIONS, HEAD`)
  * Before and after filters
  * Access to a `Rack::Response` and `Rack::Request` module
  * Ability to include Rack middleware with the `use` function
  * A fully setup session hash, which can be accessed with `session`
  * Wrapper functions for setting the response status and redirecting

## Running your application

For running your application you have two options: Run it from the file directly
or run it with `rackup`. The Pretzel suite comes with Thin as web server, so you're
good to go.

### Running the application directly

To run your application directly, you need to call one of the Rack handlers like this:

```ruby
  require "rack"
  require "pretzel/core"

  class Application < Pretzel::Core
  end

  Rack::Handler::Thin.run Application.new
```

Then you can just run the following command from the terminal: `$ ruby application.rb`
and your application should be up and running!

### Running the application via rackup

Running your application via `rackup` is a lot more flexible and is the recommended
way to get your things online. First setup your application in a file `application.rb`.

```ruby
  require "pretzel/core"

  class Application < Pretzel::Core
  end
```

Then create a new file called `config.ru`, require your application and call the
`run` function. It looks like this:

```ruby
  require_relative "application"
  run Application.new
```

Finally execute this command in the directory of your `config.ru`: `$ rackup -o "0.0.0.0" -p PORT`

The port is freely configurable, but don't forget the `-o "0.0.0.0"` part as to listen
on all available interfaces.