## Routing

Routing with the Pretzel suite is very close to Sinatra, with one exception:
The recommendation is not to do your routing in the class declaration, but outside of it.

It looks like this:

```ruby
  require "pretzel/core"

  class Application < Pretzel::Core
  end

  Application.get "/" do
    "Hello, World"
  end
```

This has the advantage, that you can split your routes into seperate files to keep
your application maintainable.

All routes are matched in order from first-declared to last-declared

### Routing methods and blocks

There are 6 routing methods available to every Pretzel applications. They are as
follows: `get, post, put, delete, options, head`. Usually, if you're not deep down
into the HTTP spec, you will probably only need the first four.

Each routing method takes a route and a block as arguments. Routes can be declared
and visited with or without a trailing slash. The suite makes no differentiation
here for simplicity purposes.[1]

```ruby
  Application.get "/test" do
    # Do stuff
  end
```

### Block variables

Within blocks you have access to various variables that allow you
to easily modify and manipulate the data flowing around. The following objects
are available:

  * request - A Rack::Request
  * response - A Rack::Response
  * parameters - A Hash containing the GET, POST and URL parameters of this route.

This follows the approach of not hiding anything from you and giving you full access

### Named parameters

Each route can have named parameters in the URL, by prefixing the part with a
colon like this: `/hello/:name`. These parameters will be added to your parameters
hash in the route block

```ruby
  # Assume we access /hello/world in our browser
  Application.get "/hello/:name" do
    "Hello, #{parameters['name']}!" # => "Hello, world!"
  end
```

----

[1] This actually made the route parsing regex more complicated, but whatever.