require_relative "setup_environment"
require "rack"

class TemplatingApplication < Pretzel::Core 
  extends Pretzel::Extension::Templating
end

TemplatingApplication.get "/" do
  render :index
end

TemplatingApplication.get "/string" do
  render "index"
end

TemplatingApplication.get "/subfolder" do
  render "complex/subfolder"
end

TemplatingApplication.get "/locals" do
  render "complex/view_with_locals", {
    "name" => "Richard"
  }
end

TemplatingApplication.get "/partial" do
  render "complex/view_with_partial"
end

TemplatingApplication.get "/no-layout" do
  render :index, {
    "layout" => false
  }
end

class TestTemplating < Minitest::Test
  include Rack::Test::Methods

  def app
    TemplatingApplication.new
  end

  def test_content_type
    get "/"
    assert_equal last_response.header["Content-Type"], "text/html"
  end

  def test_layout
    get "/"
    assert last_response.body.include? "layout"
  end

  def test_with_symbol
    get "/"
    assert last_response.body.include? "World!"
  end

  def test_with_string
    get "/string"
    assert last_response.body.include? "World!"
  end

  def test_from_subfolder
    get "/subfolder"
    assert last_response.body.include? "subfolder"
  end

  def test_with_locals
    get "/locals"
    assert last_response.body.include? "Richard"    
  end

  def test_with_partial
    get "/partial"
    assert last_response.body.include? "included"    
  end

  def test_no_layout
    get "/no-layout"
    assert_equal last_response.body.include?("layout"), false    
  end
end